Reader

Struct Reader 

pub struct Reader<D: Distance> { /* private fields */ }
A reader over the hannoy hnsw graph

Implementations

Source

impl<D: Distance> Reader<D>

pub fn open( rtxn: &RoTxn<'_>, index: u16, database: Database<D>, ) -> Result<Reader<D>>

Returns a reader over the database with the specified Distance type.

pub fn dimensions(&self) -> usize

Returns the number of dimensions in the index.

pub fn n_entrypoints(&self) -> usize

Returns the number of entry points to the hnsw index.

pub fn n_items(&self) -> u64

Returns the number of vectors stored in the index.

pub fn item_ids(&self) -> &RoaringBitmap

Returns all the item ids contained in this index.

pub fn index(&self) -> u16

Returns the index of this reader in the database.

pub fn version(&self) -> Version

Returns the version of the database.

pub fn n_nodes(&self, rtxn: &RoTxn<'_>) -> Result<Option<NonZeroUsize>>

Returns the number of nodes in the index. Useful to run an exhaustive search.

pub fn item_vector( &self, rtxn: &RoTxn<'_>, item_id: ItemId, ) -> Result<Option<Vec<f32>>>

Returns the vector for item i that was previously added.

pub fn is_empty(&self, rtxn: &RoTxn<'_>) -> Result<bool>

Returns true if the index is empty.

pub fn contains_item(&self, rtxn: &RoTxn<'_>, item_id: ItemId) -> Result<bool>

Returns true if the database contains the given item.

pub fn iter<'t>(&self, rtxn: &'t RoTxn<'_>) -> Result<ItemIter<'t, D>>

Returns an iterator over the items vector.

pub fn nns(&self, count: usize) -> QueryBuilder<'_, D>

Return a QueryBuilder that lets you configure and execute a search request.

You must provide the number of items you want to receive.