pub struct Reader<D: Distance> { /* private fields */ }Expand description
A reader over the hannoy hnsw graph
Implementations
Sourceimpl<D: Distance> Reader<D>
impl<D: Distance> Reader<D>
Sourcepub fn open(
rtxn: &RoTxn<'_>,
index: u16,
database: Database<D>,
) -> Result<Reader<D>>
pub fn open( rtxn: &RoTxn<'_>, index: u16, database: Database<D>, ) -> Result<Reader<D>>
Returns a reader over the database with the specified Distance type.
Sourcepub fn dimensions(&self) -> usize
pub fn dimensions(&self) -> usize
Returns the number of dimensions in the index.
Sourcepub fn n_entrypoints(&self) -> usize
pub fn n_entrypoints(&self) -> usize
Returns the number of entry points to the hnsw index.
Sourcepub fn item_ids(&self) -> &RoaringBitmap
pub fn item_ids(&self) -> &RoaringBitmap
Returns all the item ids contained in this index.
Sourcepub fn n_nodes(&self, rtxn: &RoTxn<'_>) -> Result<Option<NonZeroUsize>>
pub fn n_nodes(&self, rtxn: &RoTxn<'_>) -> Result<Option<NonZeroUsize>>
Returns the number of nodes in the index. Useful to run an exhaustive search.
Sourcepub fn item_vector(
&self,
rtxn: &RoTxn<'_>,
item_id: ItemId,
) -> Result<Option<Vec<f32>>>
pub fn item_vector( &self, rtxn: &RoTxn<'_>, item_id: ItemId, ) -> Result<Option<Vec<f32>>>
Returns the vector for item i that was previously added.
Sourcepub fn contains_item(&self, rtxn: &RoTxn<'_>, item_id: ItemId) -> Result<bool>
pub fn contains_item(&self, rtxn: &RoTxn<'_>, item_id: ItemId) -> Result<bool>
Returns true if the database contains the given item.
Sourcepub fn iter<'t>(&self, rtxn: &'t RoTxn<'_>) -> Result<ItemIter<'t, D>>
pub fn iter<'t>(&self, rtxn: &'t RoTxn<'_>) -> Result<ItemIter<'t, D>>
Returns an iterator over the items vector.
Sourcepub fn nns(&self, count: usize) -> QueryBuilder<'_, D>
pub fn nns(&self, count: usize) -> QueryBuilder<'_, D>
Return a QueryBuilder that lets you configure and execute a search request.
You must provide the number of items you want to receive.